/*REXX*/
/*------------------------------------------------------------------------------------ */
/* REXX script                                                                         */
/* Purpose:   Launch iKeyman GUI                                                       */
/* Author:    Trung D Nguyen/IBM                                                       */
/* Date:      08/02/2000                                                               */
/* Modifier:  Chuck McKinnis/IBM (retired)                                             */
/* Date:      15 July 2011                                                             */
/*------------------------------------------------------------------------------------ */
Call Rxfuncadd 'SysLoadFuncs','Rexxutil','SysLoadFuncs'
Call SysLoadFuncs
Trace 'n'

Parse Value Jvm_find('GSK') With java_exe java_dir class_path gsk_dir gsk_java_dir .
If Pos('JAVA11',java_dir) <> 0 Then Do
   Parse Upper Value java_dir With java_home '\BIN' .
   java_dll = java_home||'\DLL'
   java_swing = java_home||'\SWING'
End
Else Do
   Call Nojavahome
   Return 1
End
ikey_name = 'IKEYMAN_HOME'
ikeyman_home = Value(ikey_name,,'os2environment')
If ikeyman_home = '' Then Do
   Call Noikeymanhome
   Return 1
End
/* Current SwingSet needs to have the following environment due to bug
   and performance reasons */
/* iKeyman GUI will log progress messages and some other helpful messages
   when verbose mode is set. */
ikeyman_verbose = 1
/*------------------------------------------------------------------------------ */
/* Comment out the following environment setting to use a workaround to fix      */
/* JFC (SwingSet) bug related to Lightweight components, where mouse target      */
/* is lost when a JDialog is disposed and an exception message as the            */
/* following is logged.                                                          */
/*                                                                               */
/* Exception occurred during event dispatching:                                  */
/* java.lang.NullPointerException:                                               */
/* at java.awt.LightweightDispatcher.retargetMouseEvent(Container.java:1544)     */
/* at java.awt.LightweightDispatcher.processMouseEvent(Container.java:1448)      */
/* at java.awt.LightweightDispatcher.dispatchEvent(Container.java:1383)          */
/* at java.awt.Container.dispatchEventImpl(Container.java:922)                   */
/* at java.awt.Window.dispatchEventImpl(Window.java:443)                         */
/* at java.awt.Component.dispatchEvent(Component.java:1704)                      */
/* at java.awt.EventDispatchThread.run(EventDispatchThread.java:63)              */
/*                                                                               */
/* IKEYMAN will retarget the mouse after each Dialog invoked by a lightweight    */
/* component by dispatching a mouse event. This workaround seems to work well    */
/* most time. If IKEYMAN runs to crash, please turn off this fix flag and        */
/* be kind to tolerate the exception message above but ignore them.              */
/*                                                                               */
/* ikeyman_fix_jfc_mouse_retarget = 1                                            */
/*                                                                               */
/*------------------------------------------------------------------------------ */
ikeyman_fix_jfc_mouse_retarget = 0
libpaths = ikeyman_home||'\lib;'||java_dll||';'
c_path = ikeyman_home||'\classes\cfwk.zip;'||ikeyman_home||'\classes\ikmclass.jar;'
c_path = c_path||ikeyman_home||'\classes;'||ikeyman_home||'\classes\swingall.jar;'
snaroot = Value('snaroot',,'os2environment')
If snaroot <> '' Then c_path = c_path||snaroot||'\sg\sguides.jar;'
c_path = c_path||ikeyman_home||'\classes\sguides.jar;'||ikeyman_home||'\classes\sslight.jar;'
c_path = c_path||';'||java_home||'\lib\classes.zip;'||class_path

args = ''
java_flags = ''
Parse Arg all
Do i = 1 To Words(all)
   word = Word(all, i)
   arglen = Length(word)
   Select
      When word = '-classpath' Then Do
         i = i + 1
         word = Word(all, i)
         Call Doclasspath word
      End
      When word = '-v' | word = '-verbose' | word = '-verbose:class' | word = '-verbose:gc' | word = '-verbosegc' | word = '-verbose:jni' Then Call Dobothjavaikeymanverbose word
      When arglen >= 2 & Left(word, 1) = '-' Then Call Dojavaflag word
      Otherwise Call Doargs word
   End
End /* do */
Call Dorun
Return 0

/*---------------------------------------------------------------------------- */
/* Subroutine do all classpath if user specify from command line               */
/*---------------------------------------------------------------------------- */
Doclasspath:
Parse Arg word
c_path = c_path||word||';'
Return

/*---------------------------------------------------------------------------- */
/* Subroutine doBothJavaIkeymanVerbose                                         */
/*---------------------------------------------------------------------------- */
Dobothjavaikeymanverbose:
Parse Arg word
ikeyman_verbose = 1
java_flags = java_flags||word
Return

/*---------------------------------------------------------------------------- */
/* Subroutine doJavaFlag                                                       */
/*---------------------------------------------------------------------------- */
Dojavaflag:
Parse Arg word
java_flags = java_flags||word
Return

/*---------------------------------------------------------------------------- */
/* Subroutine doArgs                                                           */
/*---------------------------------------------------------------------------- */
Doargs:
Parse Arg word
args = args||word||' '
Return

/*---------------------------------------------------------------------------- */
/* Subroutine that run the Ikeyman GUI                                         */
/*---------------------------------------------------------------------------- */
Dorun:
'@ECHO ON'
t_title = Jvm_lang('ikmgui')
old_home = Value('java_home',java_home,'os2environment')
old_swing = Value('swing_home',java_swing,'os2environment')
old_libpath = SysQueryExtLIBPATH('b')
Call SysSetExtLIBPATH libpaths||';'||SysQueryExtLIBPATH('b'),'b'
old_path = Value('path',java_dir||';'||Value('path',,'os2environment'),'os2environment')
old_class = Value('classpath',c_path||';'||Value('classpath',,'os2environment'),'os2environment')
save_dir = Directory()
Call Directory gsk_java_dir
Address cmd '@start' t_title '/c /min' java_exe '-classpath' java_flags||c_path '-Dkeyman.verbose='||ikeyman_verbose '-Dkeyman.fix.jfc.mouse.retarget='||ikeyman_fix_jfc_mouse_retarget 'com.ibm.gsk.ikeyman.Ikeyman' args
Call Directory save_dir
Call Value 'classpath',old_class,'os2environment'
Call Value 'path',old_path,'os2environment'
Call SysSetExtLIBPATH old_libpath,'b'
Call Value 'swing_home',old_swing,'os2environment'
Call Value 'java_home',old_home,'os2environment'
Return

/*---------------------------------------------------------------------------- */
/* Subroutine that printout error message when JAVA_HOME is not set            */
/*---------------------------------------------------------------------------- */
Nojavahome:
Say "Error: JAVA_HOME is not set. JRE in OS2 platform is not shipped"
Say "seperately like other platforms. Instead it is embedded into java"
Say "enabled OS2 OS. If your OS is not java enabled one, please download a"
Say "OS2 JDK package 1.1.2 or its later version from IBM, and then set"
Say "JAVA_HOME to be the full path name of the home directory of JDK"
Say "installed in your host machine.  For example,"
Say "     SET JAVA_HOME=C:\java11"
Return

/*--------------------------------------------------------------------------- */
/* Subroutine that printout error message when IKEYMAN_HOME is not set      */
/*--------------------------------------------------------------------------- */
Noikeymanhome:
Say "Error: IKEYMAN_HOME is not set. Please set IKEYMAN_HOME to be the full"
Say "path name of the home directory of iKeyman package installed in your"
Say "host machine.  For example,"
Say "       SET IKEYMAN_HOME=C:\ikeyman"
Return

